@@ -3,7 +3,7 @@
 modname = 'forge'
 distname = 'cubicweb-forge'
 
-numversion = (1, 10, 1)
+numversion = (1, 10, 2)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -30,7 +30,7 @@ __depends__ = {'cubicweb': '>= 3.16.0',
                'cubicweb-testcard': None,
                'cubicweb-tracker': '>= 1.12.0',
                'cubicweb-nosylist': None,
-               'PIL': None,
+               'Pillow': None,
                }
 
 
