@@ -26,6 +26,7 @@ _ = unicode
 from yams.buildobjs import (EntityType, RelationDefinition,
                             String, Float, RichString, Bytes)
 from yams.reader import context
+from yams.constraints import IntervalBoundConstraint
 
 from cubicweb.schema import (RQLVocabularyConstraint, RRQLExpression,
                              ERQLExpression, make_workflowable)
@@ -36,7 +37,7 @@ from cubes.file.schema import File
 from cubes.card.schema import Card
 
 Project.add_relation(Bytes(description=_("project icon")), name='icon')
-Project.add_relation(String(meta=True, maxsize=50), name='icon_format')
+Project.add_relation(String(maxsize=50), name='icon_format')
 
 Project.add_relation(String(maxsize=128,
                             description=_('url to project\'s home page. Leave this field '
@@ -126,9 +127,11 @@ class ExtProject(EntityType):
 
 
 
-Ticket.add_relation(Float(description=_('load for this ticket in day.man')),
+Ticket.add_relation(Float(description=_('load for this ticket in day.man'),
+                          constraints=[IntervalBoundConstraint(minvalue=0)]),
                     name='load')
-Ticket.add_relation(Float(description=_('remaining load for this ticket in day.man')),
+Ticket.add_relation(Float(description=_('remaining load for this ticket in day.man'),
+                          constraints=[IntervalBoundConstraint(minvalue=0)]),
                     name='load_left')
 
 Ticket.get_relations('concerns').next().constraints = [
@@ -266,5 +269,5 @@ class filed_under(RelationDefinition):
     object = 'Folder'
 
 class require_permission(RelationDefinition):
-    subject = ('ExtProject', 'Comment', 'File', 'Card', 'TestInstance')
+    subject = ('Comment', 'File', 'Card', 'TestInstance')
     object = 'CWPermission'
