@@ -9,9 +9,9 @@ class AutomaticWebTest(AutomaticWebTest):
     no_auto_populate = ('TestInstance',)
     ignored_relations = set(('nosy_list',))
 
-    def post_populate(self, cursor):
-        self.commit()
-        for version in cursor.execute('Version X').entities():
+    def post_populate(self, cnx):
+        cnx.commit()
+        for version in cnx.execute('Version X').entities():
             version.cw_adapt_to('IWorkflowable').change_state('published')
 
 if __name__ == '__main__':
