@@ -25,7 +25,7 @@ class ForgeSecurityTC(SecurityTC):
     def setUp(self):
         SecurityTC.setUp(self)
         # implicitly test manager can add some entities
-        req = self.request()
-        req.create_entity('License', name=u'license')
-        self.extproject = req.create_entity('ExtProject', name=u'projet externe')
-        self.commit()
+        with self.admin_access.client_cnx() as cnx:
+            cnx.create_entity('License', name=u'license')
+            self.extprojecteid = cnx.create_entity('ExtProject', name=u'projet externe').eid
+            cnx.commit()
