@@ -8,8 +8,8 @@ __docformat__ = "restructuredtext en"
 _ = unicode
 
 from cubicweb.predicates import is_instance
-from cubicweb.web import uicfg, facet
-from cubicweb.web.views import schema
+from cubicweb.web import facet
+from cubicweb.web.views import schema, uicfg
 from cubicweb.web.views.urlrewrite import SchemaBasedRewriter, rgx, build_rset
 
 schema.SKIP_TYPES.add('see_also')
