@@ -13,9 +13,9 @@ from logilab.mtconverter import xml_escape
 from cubicweb.predicates import one_line_rset, score_entity, is_instance
 from cubicweb.view import EntityView
 from cubicweb import tags
-from cubicweb.web import uicfg, action
+from cubicweb.web import action
 from cubicweb.web.views import (primary, tabs, baseviews, tableview,
-                                idownloadable)
+                                idownloadable, uicfg)
 
 from cubes.testcard import views as testcard
 from cubes.tracker.views import fixed_orderby_rql, project as tracker
@@ -124,7 +124,7 @@ class ProjetListItemView(baseviews.SameETypeListItemView):
         self._cw.add_css('cubes.forge.css')
         entity = self.cw_rset.get_entity(row, col)
         title = xml_escape(entity.dc_title())
-        updated = entity.cw_attr_cache['modification_date'].strftime('%F, %R')
+        updated = entity.modification_date.strftime('%F, %R')
         if entity.icon:
             icon = entity.absolute_url(vid='icon')
         else:
